<?php

namespace Drupal\css_js_agg_retention\Commands;

use Drupal\Core\Asset\AssetCollectionOptimizerInterface;
use Drupal\Core\File\FileSystemInterface;
use Drush\Commands\DrushCommands;

/**
 * Drush commands for CSS/JS aggregation retention.
 */
class CssJsAggRetentionCommands extends DrushCommands {

  /**
   * The CSS collection optimizer.
   */
  protected AssetCollectionOptimizerInterface $cssOptimizer;

  /**
   * The JS collection optimizer.
   */
  protected AssetCollectionOptimizerInterface $jsOptimizer;

  /**
   * The file system service.
   */
  protected FileSystemInterface $fileSystem;

  /**
   * Constructs a new CssJsAggRetentionCommands.
   *
   * @param \Drupal\Core\Asset\AssetCollectionOptimizerInterface $css_optimizer
   *   The CSS collection optimizer.
   * @param \Drupal\Core\Asset\AssetCollectionOptimizerInterface $js_optimizer
   *   The JS collection optimizer.
   * @param \Drupal\Core\File\FileSystemInterface $file_system
   *   The file system service.
   */
  public function __construct(
    AssetCollectionOptimizerInterface $css_optimizer,
    AssetCollectionOptimizerInterface $js_optimizer,
    FileSystemInterface $file_system,
  ) {
    parent::__construct();
    $this->cssOptimizer = $css_optimizer;
    $this->jsOptimizer = $js_optimizer;
    $this->fileSystem = $file_system;
  }

  /**
   * Purge files older than threshold.
   *
   * @command css-js-agg-retention:purge-old
   * @aliases cjar:purge-old
   * @usage css-js-agg-retention:purge-old
   */
  public function purgeOld() {
    $this->output()->writeln('Purging old CSS/JS aggregates...');

    // Use the injected optimizers which include our selective deletion logic.
    $this->cssOptimizer->deleteAll();
    $this->jsOptimizer->deleteAll();

    $this->output()->writeln('Purge complete.');
  }

  /**
   * Purge everything regardless of age.
   *
   * @command css-js-agg-retention:purge-all
   * @aliases cjar:purge-all
   * @usage css-js-agg-retention:purge-all
   */
  public function purgeAll() {
    $this->output()->writeln('Purging all CSS/JS aggregates...');

    $this->fileSystem->deleteRecursive('assets://css');
    $this->fileSystem->deleteRecursive('assets://js');

    $this->output()->writeln('All aggregates purged.');
  }

}
